pub trait Sponge<Input: Field, Digest, const FULL_ROUNDS: usize> {
// Required methods
fn new(params: &'static ArithmeticSpongeParams<Input, FULL_ROUNDS>) -> Self;
fn absorb(&mut self, x: &[Input]);
fn squeeze(&mut self) -> Digest;
fn reset(&mut self);
}Expand description
Cryptographic sponge interface - for hashing an arbitrary amount of data into one or more field elements
Required Methods
Sourcefn new(params: &'static ArithmeticSpongeParams<Input, FULL_ROUNDS>) -> Self
fn new(params: &'static ArithmeticSpongeParams<Input, FULL_ROUNDS>) -> Self
Create a new cryptographic sponge using arithmetic sponge params
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".